summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorKonstantin Käfer <mail@kkaefer.com>2016-05-23 11:53:21 +0200
committerKonstantin Käfer <mail@kkaefer.com>2016-05-23 18:04:31 +0200
commit7272d7c84cf6e874b417ecd165f46f26ae7729c9 (patch)
tree76470dd1536ea632f6a75adde02bbc7af9513141 /test
parentb9f23661f88ad1982a913ff78ed39a398b53b7e3 (diff)
downloadqtlocation-mapboxgl-7272d7c84cf6e874b417ecd165f46f26ae7729c9.tar.gz
[core] move *Observers to their own files
Diffstat (limited to 'test')
-rw-r--r--test/src/mbgl/test/stub_style_observer.hpp6
-rw-r--r--test/style/style.cpp1
2 files changed, 4 insertions, 3 deletions
diff --git a/test/style/style.cpp b/test/style/style.cpp
index b60245e843..916e1121c6 100644
--- a/test/style/style.cpp
+++ b/test/style/style.cpp
@@ -2,6 +2,7 @@
#include <mbgl/test/stub_file_source.hpp>
#include <mbgl/style/style.hpp>
+#include <mbgl/source/source.hpp>
#include <mbgl/util/io.hpp>
using namespace mbgl;
diff --git a/test/src/mbgl/test/stub_style_observer.hpp b/test/src/mbgl/test/stub_style_observer.hpp
index 6b5eee189e..a0d03de8a8 100644
--- a/test/src/mbgl/test/stub_style_observer.hpp
+++ b/test/src/mbgl/test/stub_style_observer.hpp
@@ -1,14 +1,14 @@
#ifndef MBGL_TEST_STUB_STYLE_OBSERVER
#define MBGL_TEST_STUB_STYLE_OBSERVER
-#include <mbgl/style/style.hpp>
+#include <mbgl/style/style_observer.hpp>
namespace mbgl {
/**
* An implementation of Style::Observer that forwards all methods to dynamically-settable lambas.
*/
-class StubStyleObserver : public Style::Observer {
+class StubStyleObserver : public StyleObserver {
public:
void onGlyphsLoaded(const FontStack& fontStack, const GlyphRange& glyphRange) override {
if (glyphsLoaded) glyphsLoaded(fontStack, glyphRange);
@@ -1,14 +1,14 @@
namespace mbgl {
/**
- * An implementation of Style::Observer that forwards all methods to dynamically-settable lambas.
+ * An implementation of StyleObserver that forwards all methods to dynamically-settable lambas.
*/